==> tetzle_2.2.2.orig.tar.gz: tetzle-2.2.2/translations/tetzle_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Abrir imagen</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Bordes biselados</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Sombras paralelas</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Colores</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Fondo:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Sombra:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Resalte:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Falta una imagen.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Espere un momento</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Cargando la imagen…</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Generando el rompecabezas…</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Creando las piezas…</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Cargando el rompecabezas…</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Formato de datos desconocido</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>El elemento «%1» es desconocido</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Error al analizar el archivo XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Cargando las piezas…</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Obteniendo las piezas…</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Colocando las piezas…</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Acierto</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Elegir Juego</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Juegos actuales</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Partida nueva</translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Propiedades de la imagen</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etiquetas:</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccione el idioma del programa:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicie el programa para que el cambio de idioma surta efecto.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Añadir imagen</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Eliminar imagen</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Propiedades de la imagen</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 piezas</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Copiando las imágenes…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Remove selected image?</source>
        <translation>¿Quiere eliminar la imagen seleccionada?</translation>
    </message>
    <message>
        <source>Remove selected image?

There are saved games using this image that will also be removed.</source>
        <translation>Eliminar la imagen seleccionada?

Hay juegos guardados que usan esta imagen que será eliminada.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 piezas %2 %3% completo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Eliminar Juego</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Eliminar el juego seleccionado?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Vista general</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Añadir etiqueta</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Quitar etiqueta</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Sin etiqueta</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Todas las imágenes</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sin título %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Eliminar etiqueta seleccionada?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Lo Siento</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Ya existe una etiqueta con ese nombre.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Juego</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Recuperar Piezas</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Elegir</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Acercar&amp;</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Alejar&amp;</translation>
    </message>
    <message>
        <source>-</source>
        <translation>−</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Mejor &amp;Ajuste</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Mostrar R&amp;esumen</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Apariencia…</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Idioma…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controles</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controles</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Recoger Piezas:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Clic Izquierdo o Espacio</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Colocar las Piezas:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Seleccionar Piezas:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Arrastrar a la izquierda</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Rotar Piezas:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Click Derecho, Control + Clic Izquierdo o R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Arrastrar Puzzle:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Click Rueda Raton , Mayús + Clic Izquierdo, o las Flechas</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Rueda del Ratón o +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mover Cursor:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Mover el ratón o W, A, D, S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Acerca de Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Un rompecabezas que usa tetrominós como piezas</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>&amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicado bajo la licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>??%</source>
        <translation>??&#xa0;%</translation>
    </message>
    <message>
        <source>%1%</source>
        <translation>%1&#xa0;%</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Select OpenGL version.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> tetzle_3.0.1.orig.tar.gz: tetzle-3.0.1/translations/tetzle_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AddImage</name>
    <message>
        <source>Open Image</source>
        <translation>Abrir imagen</translation>
    </message>
    <message>
        <source>Images</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Appearance</source>
        <translation>Apariencia</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Opciones</translation>
    </message>
    <message>
        <source>Beveled borders</source>
        <translation>Bordes biselados</translation>
    </message>
    <message>
        <source>Drop shadows</source>
        <translation>Sombras paralelas</translation>
    </message>
    <message>
        <source>Colors</source>
        <translation>Colores</translation>
    </message>
    <message>
        <source>Background:</source>
        <translation>Fondo:</translation>
    </message>
    <message>
        <source>Shadow:</source>
        <translation>Sombra:</translation>
    </message>
    <message>
        <source>Highlight:</source>
        <translation>Resalte:</translation>
    </message>
</context>
<context>
    <name>Board</name>
    <message>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <source>Missing image.</source>
        <translation>Falta una imagen.</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Espere un momento</translation>
    </message>
    <message>
        <source>Loading image...</source>
        <translation>Cargando la imagen…</translation>
    </message>
    <message>
        <source>Generating puzzle...</source>
        <translation>Generando el rompecabezas…</translation>
    </message>
    <message>
        <source>Creating pieces...</source>
        <translation>Creando las piezas…</translation>
    </message>
    <message>
        <source>Loading puzzle...</source>
        <translation>Cargando el rompecabezas…</translation>
    </message>
    <message>
        <source>Unknown data format</source>
        <translation>Formato de datos desconocido</translation>
    </message>
    <message>
        <source>Unknown element &apos;%1&apos;</source>
        <translation>El elemento «%1» es desconocido</translation>
    </message>
    <message>
        <source>Error parsing XML file.

%1</source>
        <translation>Error al analizar el archivo XML.

%1</translation>
    </message>
    <message>
        <source>Loading pieces...</source>
        <translation>Cargando las piezas…</translation>
    </message>
    <message>
        <source>Retrieving pieces...</source>
        <translation>Obteniendo las piezas…</translation>
    </message>
    <message>
        <source>Placing pieces...</source>
        <translation>Colocando las piezas…</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Acierto</translation>
    </message>
</context>
<context>
    <name>ChooseGameDialog</name>
    <message>
        <source>Choose Game</source>
        <translation>Elegir Juego</translation>
    </message>
    <message>
        <source>Current Games</source>
        <translation>Juegos actuales</translation>
    </message>
    <message>
        <source>New Game</source>
        <translation>Partida nueva</translation>
    </message>
    <message>
        <source>Play Game</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImagePropertiesDialog</name>
    <message>
        <source>Image Properties</source>
        <translation>Propiedades de la imagen</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <source>Tags:</source>
        <translation>Etiquetas:</translation>
    </message>
    <message>
        <source>New tag name</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Seleccione el idioma del programa:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Idioma del sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Reinicie el programa para que el cambio de idioma surta efecto.</translation>
    </message>
</context>
<context>
    <name>NewGameTab</name>
    <message>
        <source>Add Image</source>
        <translation>Añadir imagen</translation>
    </message>
    <message>
        <source>Remove Image</source>
        <translation>Eliminar imagen</translation>
    </message>
    <message>
        <source>Image Properties</source>
        <translation>Propiedades de la imagen</translation>
    </message>
    <message>
        <source>%L1 pieces</source>
        <translation>%L1 piezas</translation>
    </message>
    <message>
        <source>Copying images...</source>
        <translation>Copiando las imágenes…</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
    <message numerus="yes">
        <source>Remove %n selected image(s)?</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>Saved games using these image(s) will be deleted.</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>OpenGameTab</name>
    <message>
        <source>Untitled</source>
        <translation>Sin título</translation>
    </message>
    <message>
        <source>%L1 pieces %2 %3% complete</source>
        <translation>%L1 piezas %2 %3% completo</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Delete Game</source>
        <translation>Eliminar Juego</translation>
    </message>
    <message>
        <source>Delete selected game?</source>
        <translation>Eliminar el juego seleccionado?</translation>
    </message>
</context>
<context>
    <name>Overview</name>
    <message>
        <source>Overview</source>
        <translation>Vista general</translation>
    </message>
</context>
<context>
    <name>TagManager</name>
    <message>
        <source>Add Tag</source>
        <translation>Añadir etiqueta</translation>
    </message>
    <message>
        <source>Remove Tag</source>
        <translation>Quitar etiqueta</translation>
    </message>
    <message>
        <source>Untagged</source>
        <translation>Sin etiqueta</translation>
    </message>
    <message>
        <source>All Images</source>
        <translation>Todas las imágenes</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sin título %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pregunta</translation>
    </message>
    <message>
        <source>Remove selected tag?</source>
        <translation>Eliminar etiqueta seleccionada?</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Lo Siento</translation>
    </message>
    <message>
        <source>A tag with that name already exists.</source>
        <translation>Ya existe una etiqueta con ese nombre.</translation>
    </message>
    <message>
        <source>Manage Tags...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tetzle</source>
        <translation>Tetzle</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Juego</translation>
    </message>
    <message>
        <source>&amp;Retrieve Pieces</source>
        <translation>&amp;Recuperar Piezas</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Salir</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Elegir</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Ver</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Acercar&amp;</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Alejar&amp;</translation>
    </message>
    <message>
        <source>-</source>
        <translation>−</translation>
    </message>
    <message>
        <source>Best &amp;Fit</source>
        <translation>Mejor &amp;Ajuste</translation>
    </message>
    <message>
        <source>Show O&amp;verview</source>
        <translation>Mostrar R&amp;esumen</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Tab</translation>
    </message>
    <message>
        <source>F&amp;ullscreen</source>
        <translation>&amp;Pantalla completa</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configuración</translation>
    </message>
    <message>
        <source>&amp;Appearance...</source>
        <translation>&amp;Apariencia…</translation>
    </message>
    <message>
        <source>&amp;Language...</source>
        <translation>&amp;Idioma…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Ay&amp;uda</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Controles</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Acerca de</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Acerca de &amp;Qt</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Controles</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pick Up Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Recoger Piezas:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Click or Space</source>
        <translation>Clic Izquierdo o Espacio</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drop Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Colocar las Piezas:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>&lt;b&gt;Select Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Seleccionar Piezas:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Left Drag</source>
        <translation>Arrastrar a la izquierda</translation>
    </message>
    <message>
        <source>&lt;b&gt;Rotate Pieces:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Rotar Piezas:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Right Click, Control + Left Click, or R</source>
        <translation>Click Derecho, Control + Clic Izquierdo o R</translation>
    </message>
    <message>
        <source>&lt;b&gt;Drag Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Arrastrar Puzzle:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Middle Click, Shift + Left Click, or Arrows</source>
        <translation>Click Rueda Raton , Mayús + Clic Izquierdo, o las Flechas</translation>
    </message>
    <message>
        <source>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Zoom Puzzle:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Scrollwheel or +/-</source>
        <translation>Rueda del Ratón o +/-</translation>
    </message>
    <message>
        <source>&lt;b&gt;Move Cursor:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Mover Cursor:&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Move mouse or W,A,D,S</source>
        <translation>Mover el ratón o W, A, D, S</translation>
    </message>
    <message>
        <source>About Tetzle</source>
        <translation>Acerca de Tetzle</translation>
    </message>
    <message>
        <source>A jigsaw puzzle with tetrominoes for pieces</source>
        <translation>Un rompecabezas que usa tetrominós como piezas</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>&amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Publicado bajo la licencia &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>%p% complete</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ZoomSlider</name>
    <message>
        <source>Zoom: %1%</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Images to add to the choose game dialog.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
